pub struct WasmSpendBuilder { /* private fields */ }Implementations
Sourceimpl WasmSpendBuilder
impl WasmSpendBuilder
Sourcepub fn new(
note: WasmNote,
spend_condition: WasmSpendCondition,
refund_lock: Option<WasmSpendCondition>,
) -> Result<Self, JsValue>
pub fn new( note: WasmNote, spend_condition: WasmSpendCondition, refund_lock: Option<WasmSpendCondition>, ) -> Result<Self, JsValue>
Create a new SpendBuilder with a given note and spend condition
Sourcepub fn compute_refund(&mut self, include_lock_data: bool)
pub fn compute_refund(&mut self, include_lock_data: bool)
Compute refund from any spare assets, given refund_lock was passed
Sourcepub fn cur_refund(&self) -> Option<WasmSeed>
pub fn cur_refund(&self) -> Option<WasmSeed>
Get current refund
Sourcepub fn is_balanced(&self) -> bool
pub fn is_balanced(&self) -> bool
Checks whether note.assets = seeds + fee
This function needs to return true for TxBuilder::validate to pass
Sourcepub fn seed(&mut self, seed: WasmSeed) -> Result<(), JsValue>
pub fn seed(&mut self, seed: WasmSeed) -> Result<(), JsValue>
Add seed to this spend
Seed is an output with a recipient (as defined by the spend condition).
Nockchain transaction engine will take all seeds with matching lock from all spends in the transaction, and merge them into one output note.
Sourcepub fn invalidate_sigs(&mut self)
pub fn invalidate_sigs(&mut self)
Manually invalidate signatures
Each spend’s fee+seeds are bound to one or more signatures. If they get changed, the signature becomes invalid. This builder automatically invalidates signatures upon relevant modifications, but this functionality is provided nonetheless.
Sourcepub fn missing_unlocks(&self) -> Result<Vec<JsValue>, JsValue>
pub fn missing_unlocks(&self) -> Result<Vec<JsValue>, JsValue>
Get the list of missing “unlocks”
An unlock is a spend condition to be satisfied. For instance, for a Pkh spend condition,
if the transaction is unsigned, this function will return a Pkh type missing unlock, with
the list of valid PKH’s and number of signatures needed. This will not return PKHs that are
already attatched to the spend (relevant for multisigs). For Hax spend condition, this
will return any missing preimages. This function will return a list of not-yet-validated
spend conditions.
Sourcepub fn add_preimage(
&mut self,
preimage_jam: &[u8],
) -> Result<Option<WasmDigest>, JsValue>
pub fn add_preimage( &mut self, preimage_jam: &[u8], ) -> Result<Option<WasmDigest>, JsValue>
Attatch a preimage to this spend