pub struct WasmTxBuilder { /* private fields */ }Implementations
Sourceimpl WasmTxBuilder
impl WasmTxBuilder
Sourcepub fn from_tx(
tx: WasmRawTx,
notes: Vec<WasmNote>,
spend_conditions: Vec<WasmSpendCondition>,
) -> Result<Self, JsValue>
pub fn from_tx( tx: WasmRawTx, notes: Vec<WasmNote>, spend_conditions: Vec<WasmSpendCondition>, ) -> Result<Self, JsValue>
Reconstruct a builder from raw transaction and its input notes.
To get the builder back, you must pass the notes and their corresponding spend conditions.
If serializing the builder, call WasmTxBuilder::all_notes.
Sourcepub fn simple_spend(
&mut self,
notes: Vec<WasmNote>,
spend_conditions: Vec<WasmSpendCondition>,
recipient: WasmDigest,
gift: Nicks,
fee_override: Option<Nicks>,
refund_pkh: WasmDigest,
include_lock_data: bool,
) -> Result<(), JsValue>
pub fn simple_spend( &mut self, notes: Vec<WasmNote>, spend_conditions: Vec<WasmSpendCondition>, recipient: WasmDigest, gift: Nicks, fee_override: Option<Nicks>, refund_pkh: WasmDigest, include_lock_data: bool, ) -> Result<(), JsValue>
Perform a simple-spend on this builder.
It is HIGHLY recommended to not mix simpleSpend with other types of spends.
This performs a fairly complex set of operations, in order to mimic behavior of nockchain
CLI wallet’s create-tx option. Note that we do not do 1-1 mapping of that functionality,
most notably - if recipient is the same as refund_pkh, we will create 1 seed, while the
CLI wallet will create 2.
Another difference is that you should call sign and validate after calling this method.
Internally, the transaction builder takes ALL of the notes provided, and stores them for
fee adjustments. If there are multiple notes being used, our fee setup also differs from
the CLI, because we first greedily spend the notes out, and then take fees from any
remaining refunds.
This function prioritizes using the least number of notes possible, because that lowers the fee used.
You may choose to override the fee with fee_override, but do note that validate will
fail, in case this fee is too small.
include_lock_data can be used to include %lock key in note-data, with the
SpendCondition used. However, note-data costs 1 << 15 nicks, which means, it can get
expensive.
Optional parameter remove_unused_notes, if set to false, will keep the notes in the
transaction builder. This is meant to be used whenever additional operations are performed
on the builder, such as additional spends, or addPreimage calls. All of these increase
the required fee (which can be checked with calcFee), and unused notes can then be used
to adjust fees with setFeeAndBalanceRefund or recalcAndSetFee. Once all operations are
done, one should call removeUnusedNotes to ensure these notes are not used within the
transaction.
Sourcepub fn spend(&mut self, spend: WasmSpendBuilder) -> Option<WasmSpendBuilder>
pub fn spend(&mut self, spend: WasmSpendBuilder) -> Option<WasmSpendBuilder>
Append a SpendBuilder to this transaction
Sourcepub fn set_fee_and_balance_refund(
&mut self,
fee: Nicks,
adjust_fee: bool,
include_lock_data: bool,
) -> Result<(), JsValue>
pub fn set_fee_and_balance_refund( &mut self, fee: Nicks, adjust_fee: bool, include_lock_data: bool, ) -> Result<(), JsValue>
Distributes fee across builder’s spends, and balances refunds out
adjust_fee parameter allows the fee to be slightly tweaked, whenever notes are added or
removed to/from the builder’s fee note pool. This is because using more or less notes
impacts the exact fee being required. If the caller estimates fee and sets it, adding more
notes will change the exact fee needed, and setting this parameter to true will allow one
to not have to call this function multiple times.
Sourcepub fn recalc_and_set_fee(
&mut self,
include_lock_data: bool,
) -> Result<(), JsValue>
pub fn recalc_and_set_fee( &mut self, include_lock_data: bool, ) -> Result<(), JsValue>
Recalculate fee and set it, balancing things out with refunds
Sourcepub fn add_preimage(
&mut self,
preimage_jam: &[u8],
) -> Result<Option<WasmDigest>, JsValue>
pub fn add_preimage( &mut self, preimage_jam: &[u8], ) -> Result<Option<WasmDigest>, JsValue>
Appends preimage_jam to all spend conditions that expect this preimage.
Sourcepub fn sign(&mut self, signing_key_bytes: &[u8]) -> Result<(), JsValue>
pub fn sign(&mut self, signing_key_bytes: &[u8]) -> Result<(), JsValue>
Sign the transaction with a private key.
This will sign all spends that are still missing signature from
Sourcepub fn calc_fee(&self) -> Nicks
pub fn calc_fee(&self) -> Nicks
Calculates the fee needed for the transaction.
NOTE: if the transaction is unsigned, this function will estimate the fee needed, supposing all signatures are added. However, this heuristic is only accurate for one signature. In addition, this fee calculation does not estimate the size of missing preimages.
So, first, add missing preimages, and only then calc the fee. If you’re building a multisig transaction, this value might be incorrect.
pub fn all_notes(&self) -> WasmTxNotes
pub fn build(&self) -> Result<WasmRawTx, JsValue>